@@ -147,33 +147,32 @@ struct _SizeRequest
 
 /*< private >
  * ClutterLayoutInfo:
- * @fixed_x: the fixed position of the actor, set using clutter_actor_set_x()
- * @fixed_y: the fixed position of the actor, set using clutter_actor_set_y()
+ * @fixed_pos: the fixed position of the actor
  * @margin: the composed margin of the actor
  * @x_align: the horizontal alignment, if the actor expands horizontally
  * @y_align: the vertical alignment, if the actor expands vertically
- * @min_width: the minimum width, set using clutter_actor_set_min_width()
- * @min_height: the minimum height, set using clutter_actor_set_min_height()
- * @natural_width: the natural width, set using clutter_actor_set_natural_width()
- * @natural_height: the natural height, set using clutter_actor_set_natural_height()
+ * @x_expand: whether the actor should expand horizontally
+ * @y_expand: whether the actor should expand vertically
+ * @minimum: the fixed minimum size
+ * @natural: the fixed natural size
  *
  * Ancillary layout information for an actor.
  */
 struct _ClutterLayoutInfo
 {
   /* fixed position coordinates */
-  float fixed_x;
-  float fixed_y;
+  ClutterPoint fixed_pos;
 
   ClutterMargin margin;
 
   guint x_align : 4;
   guint y_align : 4;
 
-  float min_width;
-  float min_height;
-  float natural_width;
-  float natural_height;
+  guint x_expand : 1;
+  guint y_expand : 1;
+
+  ClutterSize minimum;
+  ClutterSize natural;
 };
 
 const ClutterLayoutInfo *       _clutter_actor_get_layout_info_or_defaults      (ClutterActor *self);
@@ -296,6 +295,8 @@ void    _clutter_actor_shader_pre_paint         (ClutterActor *actor,
                                                  gboolean      repeat);
 void    _clutter_actor_shader_post_paint        (ClutterActor *actor);
 
+ClutterActorAlign       _clutter_actor_get_effective_x_align    (ClutterActor *self);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_ACTOR_PRIVATE_H__ */
