@@ -51,36 +51,10 @@
  *
  * <example id="example-clutter-bin-layout">
  *  <title>How to pack actors inside a BinLayout</title>
- *  <para>The following code shows how to build a composite actor with
- *  a texture and a background, and add controls overlayed on top. The
- *  background is set to fill the whole allocation, whilst the texture
- *  is centered; there is a control in the top right corner and a label
- *  in the bottom, filling out the whole allocated width.</para>
  *  <programlisting>
- *  ClutterLayoutManager *manager;
- *  ClutterActor *box;
- *
- *  /&ast; create the layout first &ast;/
- *  layout = clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_CENTER,
- *                                   CLUTTER_BIN_ALIGNMENT_CENTER);
- *  box = clutter_box_new (layout); /&ast; then the container &ast;/
- *
- *  /&ast; we can use the layout object to add actors &ast;/
- *  clutter_bin_layout_add (CLUTTER_BIN_LAYOUT (layout), background,
- *                          CLUTTER_BIN_ALIGNMENT_FILL,
- *                          CLUTTER_BIN_ALIGNMENT_FILL);
- *  clutter_bin_layout_add (CLUTTER_BIN_LAYOUT (layout), icon,
- *                          CLUTTER_BIN_ALIGNMENT_CENTER,
- *                          CLUTTER_BIN_ALIGNMENT_CENTER);
- *
- *  /&ast; align to the bottom left &ast;/
- *  clutter_bin_layout_add (CLUTTER_BIN_LAYOUT (layout), label,
- *                          CLUTTER_BIN_ALIGNMENT_START,
- *                          CLUTTER_BIN_ALIGNMENT_END);
- *  /&ast; align to the top right &ast;/
- *  clutter_bin_layout_add (CLUTTER_BIN_LAYOUT (layout), button,
- *                          CLUTTER_BIN_ALIGNMENT_END,
- *                          CLUTTER_BIN_ALIGNMENT_START);
+ * <xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" href="../../../../tests/interactive/test-bin-layout.c">
+ *   <xi:fallback>FIXME: MISSING XINCLUDE CONTENT</xi:fallback>
+ * </xi:include>
  *  </programlisting>
  * </example>
  *
@@ -95,10 +69,10 @@
 
 #define CLUTTER_DISABLE_DEPRECATION_WARNINGS
 #include "deprecated/clutter-container.h"
+#include "deprecated/clutter-bin-layout.h"
 
-#include "clutter-actor.h"
+#include "clutter-actor-private.h"
 #include "clutter-animatable.h"
-#include "clutter-bin-layout.h"
 #include "clutter-child-meta.h"
 #include "clutter-debug.h"
 #include "clutter-enum-types.h"
@@ -423,6 +397,27 @@ get_bin_alignment_factor (ClutterBinAlignment alignment)
   return 0.0;
 }
 
+static gdouble
+get_actor_align_factor (ClutterActorAlign alignment)
+{
+  switch (alignment)
+    {
+    case CLUTTER_ACTOR_ALIGN_CENTER:
+      return 0.5;
+
+    case CLUTTER_ACTOR_ALIGN_START:
+      return 0.0;
+
+    case CLUTTER_ACTOR_ALIGN_END:
+      return 1.0;
+
+    case CLUTTER_ACTOR_ALIGN_FILL:
+      return 0.0;
+    }
+
+  return 0.0;
+}
+
 static void
 clutter_bin_layout_allocate (ClutterLayoutManager   *manager,
                              ClutterContainer       *container,
@@ -466,10 +461,33 @@ clutter_bin_layout_allocate (ClutterLayoutManager   *manager,
       child_alloc.x2 = available_w;
       child_alloc.y2 = available_h;
 
-      x_fill = (layer->x_align == CLUTTER_BIN_ALIGNMENT_FILL);
-      y_fill = (layer->y_align == CLUTTER_BIN_ALIGNMENT_FILL);
-      x_align = get_bin_alignment_factor (layer->x_align);
-      y_align = get_bin_alignment_factor (layer->y_align);
+      if (clutter_actor_needs_expand (child, CLUTTER_ORIENTATION_HORIZONTAL))
+        {
+          ClutterActorAlign align;
+
+          align = _clutter_actor_get_effective_x_align (child);
+          x_fill = align == CLUTTER_ACTOR_ALIGN_FILL;
+          x_align = get_actor_align_factor (align);
+        }
+      else
+        {
+          x_fill = (layer->x_align == CLUTTER_BIN_ALIGNMENT_FILL);
+          x_align = get_bin_alignment_factor (layer->x_align);
+        }
+
+      if (clutter_actor_needs_expand (child, CLUTTER_ORIENTATION_VERTICAL))
+        {
+          ClutterActorAlign align;
+
+          align = clutter_actor_get_y_align (child);
+          y_fill = align == CLUTTER_ACTOR_ALIGN_FILL;
+          y_align = get_actor_align_factor (align);
+        }
+      else
+        {
+          y_fill = (layer->y_align == CLUTTER_BIN_ALIGNMENT_FILL);
+          y_align = get_bin_alignment_factor (layer->y_align);
+        }
 
       clutter_actor_allocate_align_fill (child, &child_alloc,
                                          x_align, y_align,
@@ -582,6 +600,9 @@ clutter_bin_layout_class_init (ClutterBinLayoutClass *klass)
    * by the #ClutterBinLayout
    *
    * Since: 1.2
+   *
+   * Deprecated: 1.12: Use the #ClutterActor:x-expand and the
+   *   #ClutterActor:x-align properties on #ClutterActor instead.
    */
   bin_props[PROP_X_ALIGN] =
     g_param_spec_enum ("x-align",
@@ -599,6 +620,9 @@ clutter_bin_layout_class_init (ClutterBinLayoutClass *klass)
    * by the #ClutterBinLayout
    *
    * Since: 1.2
+   *
+   * Deprecated: 1.12: Use the #ClutterActor:y-expand and the
+   *   #ClutterActor:y-align properties on #ClutterActor instead.
    */
   bin_props[PROP_Y_ALIGN] =
     g_param_spec_enum ("y-align",
@@ -669,6 +693,9 @@ clutter_bin_layout_new (ClutterBinAlignment x_align,
  * be set as the default alignment policies
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12: Use the #ClutterActor:x-align and
+ *   #ClutterActor:y-align properties of #ClutterActor instead.
  */
 void
 clutter_bin_layout_set_alignment (ClutterBinLayout    *self,
@@ -727,6 +754,9 @@ clutter_bin_layout_set_alignment (ClutterBinLayout    *self,
  * instead
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12: Use the #ClutterActor:x-align and the
+ *   #ClutterActor:y-align properties of #ClutterActor instead.
  */
 void
 clutter_bin_layout_get_alignment (ClutterBinLayout    *self,
@@ -793,6 +823,8 @@ clutter_bin_layout_get_alignment (ClutterBinLayout    *self,
  * #ClutterBinLayout
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12: Use clutter_actor_add_child() instead.
  */
 void
 clutter_bin_layout_add (ClutterBinLayout    *self,
