@@ -77,6 +77,7 @@
 
 #define CLUTTER_DISABLE_DEPRECATION_WARNINGS
 #include "deprecated/clutter-container.h"
+#include "deprecated/clutter-alpha.h"
 
 #include "clutter-box-layout.h"
 
@@ -105,9 +106,9 @@ struct _ClutterBoxLayoutPrivate
   gulong easing_mode;
   guint easing_duration;
 
-  guint is_vertical    : 1;
+  ClutterOrientation orientation;
+
   guint is_pack_start  : 1;
-  guint is_animating   : 1;
   guint use_animations : 1;
   guint is_homogeneous : 1;
 };
@@ -151,6 +152,7 @@ enum
   PROP_USE_ANIMATIONS,
   PROP_EASING_MODE,
   PROP_EASING_DURATION,
+  PROP_ORIENTATION,
 
   PROP_LAST
 };
@@ -195,19 +197,10 @@ box_child_set_align (ClutterBoxChild     *self,
   if (x_changed || y_changed)
     {
       ClutterLayoutManager *layout;
-      ClutterBoxLayout *box;
 
       layout = clutter_layout_meta_get_manager (CLUTTER_LAYOUT_META (self));
-      box = CLUTTER_BOX_LAYOUT (layout);
 
-      if (box->priv->use_animations)
-        {
-          clutter_layout_manager_begin_animation (layout,
-                                                  box->priv->easing_duration,
-                                                  box->priv->easing_mode);
-        }
-      else
-        clutter_layout_manager_layout_changed (layout);
+      clutter_layout_manager_layout_changed (layout);
 
       if (x_changed)
         g_object_notify (G_OBJECT (self), "x-align");
@@ -241,19 +234,10 @@ box_child_set_fill (ClutterBoxChild *self,
   if (x_changed || y_changed)
     {
       ClutterLayoutManager *layout;
-      ClutterBoxLayout *box;
 
       layout = clutter_layout_meta_get_manager (CLUTTER_LAYOUT_META (self));
-      box = CLUTTER_BOX_LAYOUT (layout);
 
-      if (box->priv->use_animations)
-        {
-          clutter_layout_manager_begin_animation (layout,
-                                                  box->priv->easing_duration,
-                                                  box->priv->easing_mode);
-        }
-      else
-        clutter_layout_manager_layout_changed (layout);
+      clutter_layout_manager_layout_changed (layout);
 
       if (x_changed)
         g_object_notify (G_OBJECT (self), "x-fill");
@@ -270,21 +254,12 @@ box_child_set_expand (ClutterBoxChild *self,
   if (self->expand != expand)
     {
       ClutterLayoutManager *layout;
-      ClutterBoxLayout *box;
 
       self->expand = expand;
 
       layout = clutter_layout_meta_get_manager (CLUTTER_LAYOUT_META (self));
-      box = CLUTTER_BOX_LAYOUT (layout);
 
-      if (box->priv->use_animations)
-        {
-          clutter_layout_manager_begin_animation (layout,
-                                                  box->priv->easing_duration,
-                                                  box->priv->easing_mode);
-        }
-      else
-        clutter_layout_manager_layout_changed (layout);
+      clutter_layout_manager_layout_changed (layout);
 
       g_object_notify (G_OBJECT (self), "expand");
     }
@@ -476,7 +451,7 @@ clutter_box_layout_set_container (ClutterLayoutManager *layout,
       /* we need to change the :request-mode of the container
        * to match the orientation
        */
-      request_mode = priv->is_vertical
+      request_mode = priv->orientation == CLUTTER_ORIENTATION_VERTICAL
                    ? CLUTTER_REQUEST_HEIGHT_FOR_WIDTH
                    : CLUTTER_REQUEST_WIDTH_FOR_HEIGHT;
       clutter_actor_set_request_mode (CLUTTER_ACTOR (priv->container),
@@ -497,7 +472,7 @@ get_preferred_width (ClutterBoxLayout *self,
   ClutterBoxLayoutPrivate *priv = self->priv;
   ClutterActor *child;
   gint n_children = 0;
-  gboolean is_rtl;
+  gboolean is_rtl, is_vertical;
 
   if (min_width_p)
     *min_width_p = 0;
@@ -505,7 +480,7 @@ get_preferred_width (ClutterBoxLayout *self,
   if (natural_width_p)
     *natural_width_p = 0;
 
-  if (!priv->is_vertical)
+  if (priv->orientation == CLUTTER_ORIENTATION_HORIZONTAL)
     {
       ClutterTextDirection text_dir;
 
@@ -515,6 +490,8 @@ get_preferred_width (ClutterBoxLayout *self,
   else
     is_rtl = FALSE;
 
+  is_vertical = priv->orientation == CLUTTER_ORIENTATION_VERTICAL;
+
   for (child = (is_rtl) ? clutter_actor_get_last_child (container)
                         : clutter_actor_get_first_child (container);
        child != NULL;
@@ -529,13 +506,11 @@ get_preferred_width (ClutterBoxLayout *self,
       n_children++;
 
       clutter_actor_get_preferred_width (child,
-                                         (!priv->is_vertical)
-                                           ? for_height
-                                           : -1,
+                                         !is_vertical ? for_height : -1,
                                          &child_min,
                                          &child_nat);
 
-      if (priv->is_vertical)
+      if (is_vertical)
         {
           if (min_width_p)
             *min_width_p = MAX (child_min, *min_width_p);
@@ -554,7 +529,7 @@ get_preferred_width (ClutterBoxLayout *self,
     }
 
 
-  if (!priv->is_vertical && n_children > 1)
+  if (!is_vertical && n_children > 1)
     {
       if (min_width_p)
         *min_width_p += priv->spacing * (n_children - 1);
@@ -574,7 +549,7 @@ get_preferred_height (ClutterBoxLayout *self,
   ClutterBoxLayoutPrivate *priv = self->priv;
   ClutterActor *child;
   gint n_children = 0;
-  gboolean is_rtl;
+  gboolean is_rtl, is_vertical;
 
   if (min_height_p)
     *min_height_p = 0;
@@ -582,7 +557,7 @@ get_preferred_height (ClutterBoxLayout *self,
   if (natural_height_p)
     *natural_height_p = 0;
 
-  if (!priv->is_vertical)
+  if (priv->orientation == CLUTTER_ORIENTATION_HORIZONTAL)
     {
       ClutterTextDirection text_dir;
 
@@ -592,6 +567,8 @@ get_preferred_height (ClutterBoxLayout *self,
   else
     is_rtl = FALSE;
 
+  is_vertical = priv->orientation == CLUTTER_ORIENTATION_VERTICAL;
+
   for (child = (is_rtl) ? clutter_actor_get_last_child (container)
                         : clutter_actor_get_first_child (container);
        child != NULL;
@@ -606,13 +583,11 @@ get_preferred_height (ClutterBoxLayout *self,
       n_children++;
 
       clutter_actor_get_preferred_height (child,
-                                          (priv->is_vertical)
-                                            ? for_width
-                                            : -1,
+                                          is_vertical ? for_width : -1,
                                           &child_min,
                                           &child_nat);
 
-      if (!priv->is_vertical)
+      if (!is_vertical)
         {
           if (min_height_p)
             *min_height_p = MAX (child_min, *min_height_p);
@@ -630,7 +605,7 @@ get_preferred_height (ClutterBoxLayout *self,
         }
     }
 
-  if (priv->is_vertical && n_children > 1)
+  if (is_vertical && n_children > 1)
     {
       if (min_height_p)
         *min_height_p += priv->spacing * (n_children - 1);
@@ -648,9 +623,8 @@ allocate_box_child (ClutterBoxLayout       *self,
                     ClutterAllocationFlags  flags)
 {
   ClutterBoxLayoutPrivate *priv = self->priv;
-  ClutterBoxChild         *box_child;
-  ClutterLayoutMeta       *meta;
-  ClutterActorBox          final_child_box;
+  ClutterBoxChild *box_child;
+  ClutterLayoutMeta *meta;
 
   meta = clutter_layout_manager_get_child_meta (CLUTTER_LAYOUT_MANAGER (self),
                                                 container,
@@ -663,6 +637,13 @@ allocate_box_child (ClutterBoxLayout       *self,
                 child_box->x2 - child_box->x1,
                 child_box->y2 - child_box->y1);
 
+  if (priv->use_animations)
+    {
+      clutter_actor_save_easing_state (child);
+      clutter_actor_set_easing_mode (child, priv->easing_mode);
+      clutter_actor_set_easing_duration (child, priv->easing_duration);
+    }
+
   clutter_actor_allocate_align_fill (child, child_box,
                                      get_box_alignment_factor (box_child->x_align),
                                      get_box_alignment_factor (box_child->y_align),
@@ -670,59 +651,8 @@ allocate_box_child (ClutterBoxLayout       *self,
                                      box_child->y_fill,
                                      flags);
 
-  /* retrieve the allocation computed and set by allocate_align_fill();
-   * since we call this *after* allocate(), it's just a cheap copy
-   */
-  clutter_actor_get_allocation_box (child, &final_child_box);
-
-  if (priv->use_animations && priv->is_animating)
-    {
-      ClutterLayoutManager *manager = CLUTTER_LAYOUT_MANAGER (self);
-      ClutterActorBox *start, end;
-      gdouble p;
-
-      p = clutter_layout_manager_get_animation_progress (manager);
-
-      if (!box_child->has_last_allocation)
-        {
-          /* if there is no allocation available then the child has just
-           * been added to the container; we put it in the final state
-           * and store its allocation for later
-           */
-          box_child->last_allocation = final_child_box;
-          box_child->has_last_allocation = TRUE;
-
-          return;
-        }
-
-      start = &box_child->last_allocation;
-      end = final_child_box;
-
-      /* interpolate between the initial and final values */
-      clutter_actor_box_interpolate (start, &end, p, &final_child_box);
-
-      CLUTTER_NOTE (ANIMATION,
-                    "Animate { %.1f, %.1f, %.1f, %.1f }\t"
-                     "%.3f * { %.1f, %.1f, %.1f, %.1f }\t"
-                         "-> { %.1f, %.1f, %.1f, %.1f }",
-                    start->x1, start->y1,
-                    start->x2, start->y2,
-                    p,
-                    final_child_box.x1, final_child_box.y1,
-                    final_child_box.x2, final_child_box.y2,
-                    end.x1, end.y1,
-                    end.x2, end.y2);
-
-      clutter_actor_allocate (child, &final_child_box, flags);
-    }
-  else
-    {
-      /* store the allocation for later animations */
-      box_child->last_allocation = final_child_box;
-      box_child->has_last_allocation = TRUE;
-
-      return;
-    }
+  if (priv->use_animations)
+    clutter_actor_restore_easing_state (child);
 }
 
 static void
@@ -935,7 +865,7 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
 
   sizes = g_newa (RequestedSize, nvis_children);
 
-  if (priv->is_vertical)
+  if (priv->orientation == CLUTTER_ORIENTATION_VERTICAL)
     size = box->y2 - box->y1 - (nvis_children - 1) * priv->spacing;
   else
     size = box->x2 - box->x1 - (nvis_children - 1) * priv->spacing;
@@ -950,7 +880,7 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
       if (!CLUTTER_ACTOR_IS_VISIBLE (child))
         continue;
 
-      if (priv->is_vertical)
+      if (priv->orientation == CLUTTER_ORIENTATION_VERTICAL)
         clutter_actor_get_preferred_height (child,
                                             box->x2 - box->x1,
                                             &sizes[i].minimum_size,
@@ -966,19 +896,31 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
       if (sizes[i].minimum_size < 0)
         g_error ("ClutterBoxLayout child %s minimum %s: %f < 0 for %s %f",
                  _clutter_actor_get_debug_name (child),
-                 priv->is_vertical ? "height" : "width",
+                 priv->orientation == CLUTTER_ORIENTATION_VERTICAL
+                   ? "height"
+                   : "width",
                  sizes[i].minimum_size,
-                 priv->is_vertical ? "width" : "height",
-                 priv->is_vertical ? box->x2 - box->x1 : box->y2 - box->y1);
+                 priv->orientation == CLUTTER_ORIENTATION_VERTICAL
+                   ? "width"
+                   : "height",
+                 priv->orientation == CLUTTER_ORIENTATION_VERTICAL
+                   ? box->x2 - box->x1
+                   : box->y2 - box->y1);
 
       if (sizes[i].natural_size < sizes[i].minimum_size)
         g_error ("ClutterBoxLayout child %s natural %s: %f < minimum %f for %s %f",
                  _clutter_actor_get_debug_name (child),
-                 priv->is_vertical ? "height" : "width",
+                 priv->orientation == CLUTTER_ORIENTATION_VERTICAL
+                   ? "height"
+                   : "width",
                  sizes[i].natural_size,
                  sizes[i].minimum_size,
-                 priv->is_vertical ? "width" : "height",
-                 priv->is_vertical ? box->x2 - box->x1 : box->y2 - box->y1);
+                 priv->orientation == CLUTTER_ORIENTATION_VERTICAL
+                   ? "width"
+                   : "height",
+                 priv->orientation == CLUTTER_ORIENTATION_VERTICAL
+                   ? box->x2 - box->x1
+                   : box->y2 - box->y1);
 
       size -= sizes[i].minimum_size;
 
@@ -992,7 +934,7 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
       /* If were homogenous we still need to run the above loop to get the
        * minimum sizes for children that are not going to fill
        */
-      if (priv->is_vertical)
+      if (priv->orientation == CLUTTER_ORIENTATION_VERTICAL)
         size = box->y2 - box->y1 - (nvis_children - 1) * priv->spacing;
       else
         size = box->x2 - box->x1 - (nvis_children - 1) * priv->spacing;
@@ -1017,7 +959,7 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
         extra = 0;
     }
 
-  if (!priv->is_vertical)
+  if (priv->orientation == CLUTTER_ORIENTATION_HORIZONTAL)
     {
       ClutterTextDirection text_dir;
 
@@ -1028,7 +970,7 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
     is_rtl = FALSE;
 
   /* Allocate child positions. */
-  if (priv->is_vertical)
+  if (priv->orientation == CLUTTER_ORIENTATION_VERTICAL)
     {
       child_allocation.x1 = box->x1;
       child_allocation.x2 = MAX (1.0, box->x2 - box->x1);
@@ -1091,7 +1033,7 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
         }
 
       /* Assign the child's position. */
-      if (priv->is_vertical)
+      if (priv->orientation == CLUTTER_ORIENTATION_VERTICAL)
         {
           if (box_child->y_fill)
             {
@@ -1116,7 +1058,7 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
               y += child_size + priv->spacing;
             }
         }
-      else /* !priv->is_vertical */
+      else /* CLUTTER_ORIENTATION_HORIZONTAL */
         {
           if (box_child->x_fill)
             {
@@ -1163,35 +1105,6 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
     }
 }
 
-static ClutterAlpha *
-clutter_box_layout_begin_animation (ClutterLayoutManager *manager,
-                                    guint                 duration,
-                                    gulong                easing)
-{
-  ClutterBoxLayoutPrivate *priv = CLUTTER_BOX_LAYOUT (manager)->priv;
-  ClutterLayoutManagerClass *parent_class;
-
-  priv->is_animating = TRUE;
-
-  /* we want the default implementation */
-  parent_class = CLUTTER_LAYOUT_MANAGER_CLASS (clutter_box_layout_parent_class);
-
-  return parent_class->begin_animation (manager, duration, easing);
-}
-
-static void
-clutter_box_layout_end_animation (ClutterLayoutManager *manager)
-{
-  ClutterBoxLayoutPrivate *priv = CLUTTER_BOX_LAYOUT (manager)->priv;
-  ClutterLayoutManagerClass *parent_class;
-
-  priv->is_animating = FALSE;
-
-  /* we want the default implementation */
-  parent_class = CLUTTER_LAYOUT_MANAGER_CLASS (clutter_box_layout_parent_class);
-  parent_class->end_animation (manager);
-}
-
 static void
 clutter_box_layout_set_property (GObject      *gobject,
                                  guint         prop_id,
@@ -1206,6 +1119,10 @@ clutter_box_layout_set_property (GObject      *gobject,
       clutter_box_layout_set_vertical (self, g_value_get_boolean (value));
       break;
 
+    case PROP_ORIENTATION:
+      clutter_box_layout_set_orientation (self, g_value_get_enum (value));
+      break;
+
     case PROP_HOMOGENEOUS:
       clutter_box_layout_set_homogeneous (self, g_value_get_boolean (value));
       break;
@@ -1247,7 +1164,12 @@ clutter_box_layout_get_property (GObject    *gobject,
   switch (prop_id)
     {
     case PROP_VERTICAL:
-      g_value_set_boolean (value, priv->is_vertical);
+      g_value_set_boolean (value,
+                           priv->orientation == CLUTTER_ORIENTATION_VERTICAL);
+      break;
+
+    case PROP_ORIENTATION:
+      g_value_set_enum (value, priv->orientation);
       break;
 
     case PROP_HOMOGENEOUS:
@@ -1293,8 +1215,6 @@ clutter_box_layout_class_init (ClutterBoxLayoutClass *klass)
   layout_class->allocate = clutter_box_layout_allocate;
   layout_class->set_container = clutter_box_layout_set_container;
   layout_class->get_child_meta_type = clutter_box_layout_get_child_meta_type;
-  layout_class->begin_animation = clutter_box_layout_begin_animation;
-  layout_class->end_animation = clutter_box_layout_end_animation;
 
   g_type_class_add_private (klass, sizeof (ClutterBoxLayoutPrivate));
 
@@ -1305,6 +1225,8 @@ clutter_box_layout_class_init (ClutterBoxLayoutClass *klass)
    * alongside the Y axis, instead of alongside the X axis
    *
    * Since: 1.2
+   *
+   * Deprecated: 1.12: Use #ClutterBoxLayout:orientation instead.
    */
   obj_props[PROP_VERTICAL] =
     g_param_spec_boolean ("vertical",
@@ -1312,7 +1234,26 @@ clutter_box_layout_class_init (ClutterBoxLayoutClass *klass)
                           P_("Whether the layout should be vertical, "
                              "rather than horizontal"),
                           FALSE,
-                          CLUTTER_PARAM_READWRITE);
+                          G_PARAM_READWRITE |
+                          G_PARAM_STATIC_STRINGS |
+                          G_PARAM_DEPRECATED);
+
+  /**
+   * ClutterBoxLayout:orientation:
+   *
+   * The orientation of the #ClutterBoxLayout, either horizontal
+   * or vertical
+   *
+   * Since: 1.12
+   */
+  obj_props[PROP_ORIENTATION] =
+    g_param_spec_enum ("orientation",
+                       P_("Orientation"),
+                       P_("The orientation of the layout"),
+                       CLUTTER_TYPE_ORIENTATION,
+                       CLUTTER_ORIENTATION_HORIZONTAL,
+                       G_PARAM_READWRITE |
+                       G_PARAM_STATIC_STRINGS);
 
   /**
    * ClutterBoxLayout:homogeneous:
@@ -1363,9 +1304,12 @@ clutter_box_layout_class_init (ClutterBoxLayoutClass *klass)
    * ClutterBoxLayout:use-animations:
    *
    * Whether the #ClutterBoxLayout should animate changes in the
-   * layout properties
+   * layout, overriding the easing state of the children.
    *
    * Since: 1.2
+   *
+   * Deprecated: 1.12: #ClutterBoxLayout will honour the easing state
+   *   of the children when allocating them.
    */
   obj_props[PROP_USE_ANIMATIONS] =
     g_param_spec_boolean ("use-animations",
@@ -1378,16 +1322,19 @@ clutter_box_layout_class_init (ClutterBoxLayoutClass *klass)
    * ClutterBoxLayout:easing-mode:
    *
    * The easing mode for the animations, in case
-   * #ClutterBoxLayout:use-animations is set to %TRUE
+   * #ClutterBoxLayout:use-animations is set to %TRUE.
    *
    * The easing mode has the same semantics of #ClutterAnimation:mode: it can
    * either be a value from the #ClutterAnimationMode enumeration, like
    * %CLUTTER_EASE_OUT_CUBIC, or a logical id as returned by
-   * clutter_alpha_register_func()
+   * clutter_alpha_register_func().
    *
-   * The default value is %CLUTTER_EASE_OUT_CUBIC
+   * The default value is %CLUTTER_EASE_OUT_CUBIC.
    *
    * Since: 1.2
+   *
+   * Deprecated: 1.12: The #ClutterBoxLayout will honour the easing state of
+   *   the children when allocating them.
    */
   obj_props[PROP_EASING_MODE] =
     g_param_spec_ulong ("easing-mode",
@@ -1401,11 +1348,14 @@ clutter_box_layout_class_init (ClutterBoxLayoutClass *klass)
    * ClutterBoxLayout:easing-duration:
    *
    * The duration of the animations, in case #ClutterBoxLayout:use-animations
-   * is set to %TRUE
+   * is set to %TRUE.
    *
-   * The duration is expressed in milliseconds
+   * The duration is expressed in milliseconds.
    *
    * Since: 1.2
+   *
+   * Deprecated: 1.12: The #ClutterBoxLayout will honour the easing state of
+   *   the children when allocating them.
    */
   obj_props[PROP_EASING_DURATION] =
     g_param_spec_uint ("easing-duration",
@@ -1427,7 +1377,7 @@ clutter_box_layout_init (ClutterBoxLayout *layout)
 
   layout->priv = priv = CLUTTER_BOX_LAYOUT_GET_PRIVATE (layout);
 
-  priv->is_vertical = FALSE;
+  priv->orientation = CLUTTER_ORIENTATION_HORIZONTAL;
   priv->is_homogeneous = FALSE;
   priv->is_pack_start = FALSE;
   priv->spacing = 0;
@@ -1479,14 +1429,7 @@ clutter_box_layout_set_spacing (ClutterBoxLayout *layout,
 
       manager = CLUTTER_LAYOUT_MANAGER (layout);
 
-      if (priv->use_animations)
-        {
-          clutter_layout_manager_begin_animation (manager,
-                                                  priv->easing_duration,
-                                                  priv->easing_mode);
-        }
-      else
-        clutter_layout_manager_layout_changed (manager);
+      clutter_layout_manager_layout_changed (manager);
 
       g_object_notify (G_OBJECT (layout), "spacing");
     }
@@ -1519,36 +1462,57 @@ clutter_box_layout_get_spacing (ClutterBoxLayout *layout)
  * the Y axis, instead of horizontally alongside the X axis
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12: Use clutter_box_layout_set_orientation() instead.
  */
 void
 clutter_box_layout_set_vertical (ClutterBoxLayout *layout,
                                  gboolean          vertical)
+{
+  ClutterOrientation new_orientation, old_orientation;
+
+  g_return_if_fail (CLUTTER_IS_BOX_LAYOUT (layout));
+
+  old_orientation = layout->priv->orientation;
+  new_orientation = vertical
+                  ? CLUTTER_ORIENTATION_VERTICAL
+                  : CLUTTER_ORIENTATION_HORIZONTAL;
+  clutter_box_layout_set_orientation (layout, new_orientation);
+
+  if (old_orientation != new_orientation)
+    g_object_notify_by_pspec (G_OBJECT (layout), obj_props[PROP_VERTICAL]);
+}
+
+/**
+ * clutter_box_layout_set_orientation:
+ * @layout: a #ClutterBoxLayout
+ * @orientation: the orientation of the #ClutterBoxLayout
+ *
+ * Sets the orientation of the #ClutterBoxLayout layout manager.
+ *
+ * Since: 1.12
+ */
+void
+clutter_box_layout_set_orientation (ClutterBoxLayout   *layout,
+                                    ClutterOrientation  orientation)
 {
   ClutterBoxLayoutPrivate *priv;
+  ClutterLayoutManager *manager;
 
   g_return_if_fail (CLUTTER_IS_BOX_LAYOUT (layout));
 
   priv = layout->priv;
 
-  if (priv->is_vertical != vertical)
-    {
-      ClutterLayoutManager *manager;
+  if (priv->orientation == orientation)
+    return;
 
-      priv->is_vertical = vertical ? TRUE : FALSE;
+  priv->orientation = orientation;
 
-      manager = CLUTTER_LAYOUT_MANAGER (layout);
+  manager = CLUTTER_LAYOUT_MANAGER (layout);
 
-      if (priv->use_animations)
-        {
-          clutter_layout_manager_begin_animation (manager,
-                                                  priv->easing_duration,
-                                                  priv->easing_mode);
-        }
-      else
-        clutter_layout_manager_layout_changed (manager);
+  clutter_layout_manager_layout_changed (manager);
 
-      g_object_notify (G_OBJECT (layout), "vertical");
-    }
+  g_object_notify_by_pspec (G_OBJECT (layout), obj_props[PROP_ORIENTATION]);
 }
 
 /**
@@ -1562,13 +1526,34 @@ clutter_box_layout_set_vertical (ClutterBoxLayout *layout,
  *   vertically, and %FALSE otherwise
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12: Use clutter_box_layout_get_orientation() instead
  */
 gboolean
 clutter_box_layout_get_vertical (ClutterBoxLayout *layout)
 {
   g_return_val_if_fail (CLUTTER_IS_BOX_LAYOUT (layout), FALSE);
 
-  return layout->priv->is_vertical;
+  return layout->priv->orientation == CLUTTER_ORIENTATION_VERTICAL;
+}
+
+/**
+ * clutter_box_layout_get_orientation:
+ * @layout: a #ClutterBoxLayout
+ *
+ * Retrieves the orientation of the @layout.
+ *
+ * Return value: the orientation of the layout
+ *
+ * Since: 1.12
+ */
+ClutterOrientation
+clutter_box_layout_get_orientation (ClutterBoxLayout *layout)
+{
+  g_return_val_if_fail (CLUTTER_IS_BOX_LAYOUT (layout),
+                        CLUTTER_ORIENTATION_HORIZONTAL);
+
+  return layout->priv->orientation;
 }
 
 /**
@@ -1599,14 +1584,7 @@ clutter_box_layout_set_homogeneous (ClutterBoxLayout *layout,
 
       manager = CLUTTER_LAYOUT_MANAGER (layout);
 
-      if (priv->use_animations)
-        {
-          clutter_layout_manager_begin_animation (manager,
-                                                  priv->easing_duration,
-                                                  priv->easing_mode);
-        }
-      else
-        clutter_layout_manager_layout_changed (manager);
+      clutter_layout_manager_layout_changed (manager);
 
       g_object_notify (G_OBJECT (layout), "homogeneous");
     }
@@ -1660,14 +1638,7 @@ clutter_box_layout_set_pack_start (ClutterBoxLayout *layout,
 
       manager = CLUTTER_LAYOUT_MANAGER (layout);
 
-      if (priv->use_animations)
-        {
-          clutter_layout_manager_begin_animation (manager,
-                                                  priv->easing_duration,
-                                                  priv->easing_mode);
-        }
-      else
-        clutter_layout_manager_layout_changed (manager);
+      clutter_layout_manager_layout_changed (manager);
 
       g_object_notify (G_OBJECT (layout), "pack-start");
     }
@@ -2081,9 +2052,16 @@ clutter_box_layout_get_expand (ClutterBoxLayout *layout,
  *
  * The duration of the animations is controlled by
  * clutter_box_layout_set_easing_duration(); the easing mode to be used
- * by the animations is controlled by clutter_box_layout_set_easing_mode()
+ * by the animations is controlled by clutter_box_layout_set_easing_mode().
+ *
+ * Enabling animations will override the easing state of each child
+ * of the actor using @layout, and will use the #ClutterBoxLayout:easing-mode
+ * and #ClutterBoxLayout:easing-duration properties instead.
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12: The layout manager will honour the easing state
+ *   of the children when allocating them.
  */
 void
 clutter_box_layout_set_use_animations (ClutterBoxLayout *layout,
@@ -2107,13 +2085,13 @@ clutter_box_layout_set_use_animations (ClutterBoxLayout *layout,
  * clutter_box_layout_get_use_animations:
  * @layout: a #ClutterBoxLayout
  *
- * Retrieves whether @layout should animate changes in the layout properties
- *
- * Since clutter_box_layout_set_use_animations()
+ * Retrieves whether @layout should animate changes in the layout properties.
  *
  * Return value: %TRUE if the animations should be used, %FALSE otherwise
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12
  */
 gboolean
 clutter_box_layout_get_use_animations (ClutterBoxLayout *layout)
@@ -2130,12 +2108,12 @@ clutter_box_layout_get_use_animations (ClutterBoxLayout *layout)
  *   from clutter_alpha_register_func()
  *
  * Sets the easing mode to be used by @layout when animating changes in layout
- * properties
- *
- * Use clutter_box_layout_set_use_animations() to enable and disable the
- * animations
+ * properties.
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12: The layout manager will honour the easing state
+ *   of the children when allocating them.
  */
 void
 clutter_box_layout_set_easing_mode (ClutterBoxLayout *layout,
@@ -2164,6 +2142,8 @@ clutter_box_layout_set_easing_mode (ClutterBoxLayout *layout,
  * Return value: an easing mode
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12
  */
 gulong
 clutter_box_layout_get_easing_mode (ClutterBoxLayout *layout)
@@ -2180,12 +2160,12 @@ clutter_box_layout_get_easing_mode (ClutterBoxLayout *layout)
  * @msecs: the duration of the animations, in milliseconds
  *
  * Sets the duration of the animations used by @layout when animating changes
- * in the layout properties
- *
- * Use clutter_box_layout_set_use_animations() to enable and disable the
- * animations
+ * in the layout properties.
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12: The layout manager will honour the easing state
+ *   of the children when allocating them.
  */
 void
 clutter_box_layout_set_easing_duration (ClutterBoxLayout *layout,
@@ -2214,6 +2194,8 @@ clutter_box_layout_set_easing_duration (ClutterBoxLayout *layout,
  * Return value: the duration of the animations, in milliseconds
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12
  */
 guint
 clutter_box_layout_get_easing_duration (ClutterBoxLayout *layout)
