@@ -467,6 +467,9 @@ typedef enum {
  * The alignment policies available on each axis for #ClutterBinLayout
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.12: Use #ClutterActorAlign and the #ClutterActor
+ *   API instead
  */
 typedef enum {
   CLUTTER_BIN_ALIGNMENT_FIXED,
@@ -541,7 +544,7 @@ typedef enum {
  * @CLUTTER_LONG_PRESS_ACTIVATE: Activates the action on a long press
  * @CLUTTER_LONG_PRESS_CANCEL: The long press was cancelled
  *
- * The states for the #ClutterClikAction::long-press signal.
+ * The states for the #ClutterClickAction::long-press signal.
  *
  * Since: 1.8
  */
@@ -893,6 +896,9 @@ typedef enum {
  * @CLUTTER_INPUT_AXIS_XTILT: The tilt on the X axis
  * @CLUTTER_INPUT_AXIS_YTILT: The tile on the Y axis
  * @CLUTTER_INPUT_AXIS_WHEEL: A wheel
+ * @CLUTTER_INPUT_AXIS_DISTANCE: Distance (Since 1.12)
+ * @CLUTTER_INPUT_AXIS_LAST: Last value of the enumeration; this value is
+ *   useful when iterating over the enumeration values (Since 1.12)
  *
  * The type of axes Clutter recognizes on a #ClutterInputDevice
  *
@@ -900,12 +906,16 @@ typedef enum {
  */
 typedef enum {
   CLUTTER_INPUT_AXIS_IGNORE,
+
   CLUTTER_INPUT_AXIS_X,
   CLUTTER_INPUT_AXIS_Y,
   CLUTTER_INPUT_AXIS_PRESSURE,
   CLUTTER_INPUT_AXIS_XTILT,
   CLUTTER_INPUT_AXIS_YTILT,
-  CLUTTER_INPUT_AXIS_WHEEL
+  CLUTTER_INPUT_AXIS_WHEEL,
+  CLUTTER_INPUT_AXIS_DISTANCE,
+
+  CLUTTER_INPUT_AXIS_LAST
 } ClutterInputAxis;
 
 /**
@@ -1189,6 +1199,40 @@ typedef enum {
   CLUTTER_SCALING_FILTER_TRILINEAR
 } ClutterScalingFilter;
 
+/**
+ * ClutterOrientation:
+ * @CLUTTER_ORIENTATION_HORIZONTAL: An horizontal orientation
+ * @CLUTTER_ORIENTATION_VERTICAL: A vertical orientation
+ *
+ * Represents the orientation of actors or layout managers.
+ *
+ * Since: 1.12
+ */
+typedef enum {
+  CLUTTER_ORIENTATION_HORIZONTAL,
+  CLUTTER_ORIENTATION_VERTICAL
+} ClutterOrientation;
+
+/**
+ * ClutterScrollMode:
+ * @CLUTTER_SCROLL_NONE: Ignore scrolling
+ * @CLUTTER_SCROLL_HORIZONTALLY: Scroll only horizontally
+ * @CLUTTER_SCROLL_VERTICALLY: Scroll only vertically
+ * @CLUTTER_SCROLL_BOTH: Scroll in both directions
+ *
+ * Scroll modes.
+ *
+ * Since: 1.12
+ */
+typedef enum { /*< prefix=CLUTTER_SCROLL >*/
+  CLUTTER_SCROLL_NONE         = 0,
+
+  CLUTTER_SCROLL_HORIZONTALLY = 1 << 0,
+  CLUTTER_SCROLL_VERTICALLY   = 1 << 1,
+
+  CLUTTER_SCROLL_BOTH         = CLUTTER_SCROLL_HORIZONTALLY | CLUTTER_SCROLL_VERTICALLY
+} ClutterScrollMode;
+
 G_END_DECLS
 
 #endif /* __CLUTTER_ENUMS_H__ */
