@@ -42,10 +42,10 @@
  *   keyframe = clutter_keyframe_transition_new ("opacity");
  *   clutter_transition_set_from (keyframe, G_TYPE_UINT, 255);
  *   clutter_transition_set_to (keyframe, G_TYPE_UINT, 0);
- *   clutter_keyframe_transition_set (CLUTTER_KEYFRAME_TRANSITION (keyframe),
- *                                    G_TYPE_UINT,
- *                                    1, /&ast; number of key frames &ast;/
- *                                    0.5, 128, CLUTTER_EASE_IN_OUT_CUBIC);
+ *   clutter_keyframe_transition_set_keys (CLUTTER_KEYFRAME_TRANSITION (keyframe),
+ *                                         G_TYPE_UINT,
+ *                                         1, /&ast; number of key frames &ast;/
+ *                                         0.5, 128, CLUTTER_EASE_IN_OUT_CUBIC);
  * ]|
  *
  * The example above sets up a keyframe transition for the #ClutterActor:opacity
@@ -96,9 +96,9 @@ struct _ClutterKeyframeTransitionPrivate
   gint current_frame;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (ClutterKeyframeTransition,
-                            clutter_keyframe_transition,
-                            CLUTTER_TYPE_PROPERTY_TRANSITION)
+G_DEFINE_TYPE (ClutterKeyframeTransition,
+               clutter_keyframe_transition,
+               CLUTTER_TYPE_PROPERTY_TRANSITION)
 
 static void
 key_frame_free (gpointer data)
@@ -375,6 +375,8 @@ clutter_keyframe_transition_class_init (ClutterKeyframeTransitionClass *klass)
   ClutterTimelineClass *timeline_class = CLUTTER_TIMELINE_CLASS (klass);
   ClutterTransitionClass *transition_class = CLUTTER_TRANSITION_CLASS (klass);
 
+  g_type_class_add_private (klass, sizeof (ClutterKeyframeTransitionPrivate));
+
   gobject_class->finalize = clutter_keyframe_transition_finalize;
 
   timeline_class->started = clutter_keyframe_transition_started;
@@ -386,7 +388,9 @@ clutter_keyframe_transition_class_init (ClutterKeyframeTransitionClass *klass)
 static void
 clutter_keyframe_transition_init (ClutterKeyframeTransition *self)
 {
-  self->priv = clutter_keyframe_transition_get_instance_private (self);
+  self->priv =
+    G_TYPE_INSTANCE_GET_PRIVATE (self, CLUTTER_TYPE_KEYFRAME_TRANSITION,
+                                 ClutterKeyframeTransitionPrivate);
 }
 
 /**
@@ -489,12 +493,7 @@ clutter_keyframe_transition_set_values (ClutterKeyframeTransition *transition,
     {
       KeyFrame *frame = &g_array_index (priv->frames, KeyFrame, i);
 
-      if (frame->interval)
-        clutter_interval_set_final_value (frame->interval, &values[i]);
-      else
-        frame->interval =
-          clutter_interval_new_with_values (G_VALUE_TYPE (&values[i]), NULL,
-                                            &values[i]);
+      clutter_interval_set_final_value (frame->interval, &values[i]);
     }
 }
 
@@ -552,7 +551,7 @@ clutter_keyframe_transition_set_modes (ClutterKeyframeTransition  *transition,
  * Sets the key frames of the @transition.
  *
  * This variadic arguments function is a convenience for C developers;
- * language bindings should use clutter_keyframe_transition_set_key_frames(),
+ * language bindings should use clutter_keyframe_transition_set_keys(),
  * clutter_keyframe_transition_set_modes(), and
  * clutter_keyframe_transition_set_values() instead.
  *
