@@ -35,17 +35,16 @@
 #include "clutter-actor.h"
 #include "clutter-actor-meta.h"
 #include "clutter-align-constraint.h"
-#include "clutter-alpha.h"
 #include "clutter-animatable.h"
-#include "clutter-animation.h"
-#include "clutter-animator.h"
 #include "clutter-backend.h"
 #include "clutter-bind-constraint.h"
 #include "clutter-binding-pool.h"
 #include "clutter-bin-layout.h"
 #include "clutter-blur-effect.h"
 #include "clutter-box-layout.h"
-#include "clutter-cairo-texture.h"
+#include "clutter-brightness-contrast-effect.h"
+#include "clutter-cairo.h"
+#include "clutter-canvas.h"
 #include "clutter-child-meta.h"
 #include "clutter-click-action.h"
 #include "clutter-clone.h"
@@ -54,6 +53,7 @@
 #include "clutter-colorize-effect.h"
 #include "clutter-constraint.h"
 #include "clutter-container.h"
+#include "clutter-content.h"
 #include "clutter-deform-effect.h"
 #include "clutter-desaturate-effect.h"
 #include "clutter-device-manager.h"
@@ -67,22 +67,27 @@
 #include "clutter-flow-layout.h"
 #include "clutter-gesture-action.h"
 #include "clutter-group.h"
+#include "clutter-image.h"
 #include "clutter-input-device.h"
 #include "clutter-interval.h"
+#include "clutter-keyframe-transition.h"
 #include "clutter-keysyms.h" 
 #include "clutter-layout-manager.h"
 #include "clutter-layout-meta.h"
 #include "clutter-list-model.h"
 #include "clutter-macros.h"
 #include "clutter-main.h"
-#include "clutter-media.h"
 #include "clutter-model.h"
 #include "clutter-offscreen-effect.h"
 #include "clutter-page-turn-effect.h"
+#include "clutter-paint-nodes.h"
+#include "clutter-paint-node.h"
 #include "clutter-path-constraint.h"
 #include "clutter-path.h"
+#include "clutter-property-transition.h"
 #include "clutter-scriptable.h"
 #include "clutter-script.h"
+#include "clutter-scroll-actor.h"
 #include "clutter-settings.h"
 #include "clutter-shader-effect.h"
 #include "clutter-shader-types.h"
@@ -90,11 +95,12 @@
 #include "clutter-snap-constraint.h"
 #include "clutter-stage.h"
 #include "clutter-stage-manager.h"
-#include "clutter-state.h"
 #include "clutter-table-layout.h"
 #include "clutter-texture.h"
 #include "clutter-text.h"
 #include "clutter-timeline.h"
+#include "clutter-transition-group.h"
+#include "clutter-transition.h"
 #include "clutter-units.h"
 #include "clutter-version.h"
 
