@@ -74,8 +74,6 @@
 #include <cairo-gobject.h>
 
 #define CLUTTER_DISABLE_DEPRECATION_WARNINGS
-#include "deprecated/clutter-texture.h"
-#include "deprecated/clutter-cairo-texture.h"
 
 #include "clutter-cairo-texture.h"
 
@@ -86,17 +84,11 @@
 #include "clutter-marshal.h"
 #include "clutter-private.h"
 
-struct _ClutterCairoTexturePrivate
-{
-  cairo_surface_t *cr_surface;
+#include "deprecated/clutter-cairo-texture.h"
 
-  guint surface_width;
-  guint surface_height;
-
-  cairo_t *cr_context;
-
-  guint auto_resize : 1;
-};
+G_DEFINE_TYPE (ClutterCairoTexture,
+               clutter_cairo_texture,
+               CLUTTER_TYPE_TEXTURE);
 
 enum
 {
@@ -121,10 +113,6 @@ static GParamSpec *obj_props[PROP_LAST] = { NULL, };
 
 static guint cairo_signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE_WITH_PRIVATE (ClutterCairoTexture,
-                            clutter_cairo_texture,
-                            CLUTTER_TYPE_TEXTURE)
-
 #ifdef CLUTTER_ENABLE_DEBUG
 #define clutter_warn_if_paint_fail(obj)                 G_STMT_START {  \
   if (CLUTTER_ACTOR_IN_PAINT (obj)) {                                   \
@@ -136,6 +124,20 @@ G_DEFINE_TYPE_WITH_PRIVATE (ClutterCairoTexture,
 #define clutter_warn_if_paint_fail(obj)         /* void */
 #endif /* CLUTTER_ENABLE_DEBUG */
 
+#define CLUTTER_CAIRO_TEXTURE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_CAIRO_TEXTURE, ClutterCairoTexturePrivate))
+
+struct _ClutterCairoTexturePrivate
+{
+  cairo_surface_t *cr_surface;
+
+  guint surface_width;
+  guint surface_height;
+
+  cairo_t *cr_context;
+
+  guint auto_resize : 1;
+};
+
 typedef struct {
   ClutterCairoTexture *texture;
 
@@ -345,6 +347,9 @@ clutter_cairo_texture_emit_draw (ClutterCairoTexture        *self,
   g_assert (self->priv->cr_surface != NULL);
 
   cr = cairo_create (self->priv->cr_surface);
+  cairo_set_user_data (cr, &clutter_cairo_texture_context_key,
+                       ctxt,
+                       clutter_cairo_texture_context_destroy);
 
   if (ctxt->is_clipped)
     {
@@ -363,8 +368,6 @@ clutter_cairo_texture_emit_draw (ClutterCairoTexture        *self,
 
   self->priv->cr_context = NULL;
 
-  clutter_cairo_texture_context_destroy (ctxt);
-
   cairo_destroy (cr);
 }
 
@@ -578,6 +581,8 @@ clutter_cairo_texture_class_init (ClutterCairoTextureClass *klass)
 
   klass->create_surface = clutter_cairo_texture_create_surface;
 
+  g_type_class_add_private (gobject_class, sizeof (ClutterCairoTexturePrivate));
+
   /**
    * ClutterCairoTexture:surface-width:
    *
@@ -707,7 +712,9 @@ clutter_cairo_texture_class_init (ClutterCairoTextureClass *klass)
 static void
 clutter_cairo_texture_init (ClutterCairoTexture *self)
 {
-  self->priv = clutter_cairo_texture_get_instance_private (self);
+  ClutterCairoTexturePrivate *priv;
+
+  self->priv = priv = CLUTTER_CAIRO_TEXTURE_GET_PRIVATE (self);
 
   /* FIXME - we are hardcoding the format; it would be good to have
    * a :surface-format construct-only property for creating
