@@ -75,20 +75,28 @@ on_button_press (ClutterActor       *actor,
       clutter_text_set_text (CLUTTER_TEXT (easing_mode_label), text);
       g_free (text);
     }
+  else if (event->button == CLUTTER_BUTTON_MIDDLE)
+    {
+      clutter_actor_set_position (rectangle, event->x, event->y);
+    }
   else if (event->button == CLUTTER_BUTTON_PRIMARY)
     {
       ClutterAnimationMode cur_mode;
 
       cur_mode = easing_modes[current_mode].mode;
 
+      clutter_actor_save_easing_state (rectangle);
+
       /* tween the actor using the current easing mode */
       clutter_actor_set_easing_mode (rectangle, cur_mode);
       clutter_actor_set_easing_duration (rectangle, duration * 1000);
 
       clutter_actor_set_position (rectangle, event->x, event->y);
+
+      clutter_actor_restore_easing_state (rectangle);
     }
 
-  return TRUE;
+  return CLUTTER_EVENT_STOP;
 }
 
 static gboolean
